[![Color fonts](https://see.fontimg.com/api/renderfont4/GO6zm/eyJyIjoiZHciLCJoIjoxODIsInciOjIwMDAsImZzIjo5MSwiZmdjIjoiIzIxQkNDNSIsImJnYyI6IiNGRkZGRkYifQ/T1BUSSBmb2xpbw/fattern.png)](https://www.fontspace.com/category/color)

--------------------------------------

![PyPI Version](https://img.shields.io/pypi/v/pypo.svg)


**OptiFolio** is a package for portfolio optimization.

-   Documentation: (COMING SOON) <https://pypo.readthedocs.io>.

> **NOTE**
>
> This project is in early stage development, and can thus go trough major changes.

Features
--------

-   TODO

